/* 
 * Field.java
 * Aaron Mller (164750) und Beatrice Fischer (164718)
 */

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.border.*;

public class Field extends JTextField implements KeyListener {
	private static final long serialVersionUID = 1L;

	private int keyCode = 0;
	
	public int posX, posY;	// Position im Wrfel
	public Cube cube;		// Assiziation

	Field(int posX, int posY, Cube cube) {
		this.posX = posX;
		this.posY = posY;
		this.cube = cube;
		
		setPreferredSize(new Dimension(30, 30));
		setHorizontalAlignment(JTextField.CENTER);
		setFont(new Font("Verdana Bold", 0, 25));
		setBorder(new LineBorder(Color.BLACK));
		
		this.addKeyListener(this);
	}
	
	public void setImpossible(boolean b) {
		Color c = (b) ? Color.RED : Color.WHITE;
		setBackground(c);
	}
	
	public void setFixed(boolean f) {
		setEditable(f?false:true);
		setBackground(f?Color.LIGHT_GRAY:Color.WHITE);
	}
	
	public void setColor(Color c) {
		setBackground(c);
	}
	
	public void setNumber(int n) {
		if (n == -1) {
			setText("");
		} else {
			setText(Integer.toString(n));
		}
	}
	
	public int getNumber() {
		if (this.getText().equals("")) {
			return -1;
		} else {
			return Integer.parseInt(this.getText());
		}
	}
	
	public void setInitialNumber(int n) {
		this.setNumber(n);
		this.setFixed(true);
	}
	
	public void keyPressed(KeyEvent e) { 
		keyCode = e.getKeyCode();
	}
	
	public void keyTyped(KeyEvent e) {	
		// Ist schon eine Taste gedrckt worden?
		if(this.getText().length() >= 1) {
			switch (this.keyCode) {
				// Spezialtasten zulassen
				case KeyEvent.VK_ENTER:
				case KeyEvent.VK_BACK_SPACE:
				case KeyEvent.VK_DELETE:
				case KeyEvent.VK_RIGHT:
				case KeyEvent.VK_LEFT:
				case KeyEvent.VK_DOWN:
				case KeyEvent.VK_UP:
					break;
				// Alles andere "essen"
				default: {
					e.consume();
					return;
				}			
			}
			
		// Feld war noch leer	
		} else {
			switch (this.keyCode) {
				// Spezialtasten zulassen
				case KeyEvent.VK_BACK_SPACE: {
					this.setImpossible(false);
					break;
				}
				case KeyEvent.VK_ENTER:
				case KeyEvent.VK_DELETE:
				case KeyEvent.VK_RIGHT:
				case KeyEvent.VK_LEFT:
				case KeyEvent.VK_DOWN:
				case KeyEvent.VK_UP:
				
				// Zahlen zulassen
				case KeyEvent.VK_1:
				case KeyEvent.VK_2:
				case KeyEvent.VK_3:
				case KeyEvent.VK_4:
				case KeyEvent.VK_5:
				case KeyEvent.VK_6:
				case KeyEvent.VK_7:
				case KeyEvent.VK_8:
				case KeyEvent.VK_9:
					break;
				// Alles andere "essen"
				default: {
					e.consume();
					return;
				}
			}
		}
		
		// Editor?
		if (cube.board.frame.wt == 2) {
			if (cube.board.frame.bField.isSelected() == true) {
				this.setFixed(false);			
			} else {
				this.setFixed(true);
				this.setEditable(true);
			}
		}
	}

	public void keyReleased(KeyEvent e) {
		JTextField tf = (JTextField)e.getSource();
		
		// Aktionen
		int n = tf.getText().equals("") ? -1 : Integer.parseInt(tf.getText());
		this.cube.board.checkNumber(this, n);	// Nummer Prfen
		this.cube.board.updateUndo(this, n);	// Undo-Schritt aktualisieren
		
		// Spiel gelst?
		if (cube.board.frame.wt < 2) {
			if (this.cube.board.isPuzzleSolved()) {
				JOptionPane.showMessageDialog(this.cube.board.frame,
					"Das Sudoku ist gelst!",
					"Gewonnen!", JOptionPane.PLAIN_MESSAGE);
			}
		}
	}
}
