/* 
 * IntFrame.java
 * Aaron Mller (164750) und Beatrice Fischer (164718)
 */

import java.awt.*;
import javax.swing.*;
import javax.swing.filechooser.FileFilter;
import java.awt.event.*;
import java.io.*;

public class IntFrame extends JInternalFrame implements ActionListener {
	private static final long serialVersionUID = 1L;
	private JToolBar toolBar = new JToolBar();
	public JPanel pBoard = new JPanel();
	private JFileChooser saveDialog = new JFileChooser(new File("./"));
	
	private Icon 
		iconExit = new ImageIcon(getClass().getResource("images/close.png")),
		iconSave = new ImageIcon(getClass().getResource("images/save.png")),
		iconUndo = new ImageIcon(getClass().getResource("images/undo.png")),
		iconEditable = new ImageIcon(getClass().getResource("images/field_editable.png")),
		iconFixed = new ImageIcon(getClass().getResource("images/field_fixed.png")),
		iconFrame = new ImageIcon(getClass().getResource("images/frame_icon.png")),
		iconEditor = new ImageIcon(getClass().getResource("images/menu_editor.png"));
	private JButton
		bExit = new JButton(iconExit),
		bSave = new JButton(iconSave),
		bUndo = new JButton(iconUndo);	
	public JToggleButton
		bField = new JToggleButton(iconFixed);
	
	SuDoKu rootWindow;
	Board board;
	GameData gameData;
	int wt;
	
	public IntFrame(SuDoKu m, int wt, int difficulty, GameData gd) {
		rootWindow = m;
		this.wt = wt;
		
		this.gameData = gd;
		
		this.setSize(300, 361);
		this.setResizable(false);
		
		// Fr beide Ansichten gleich
		bExit.setActionCommand("bExit");
		bSave.setActionCommand("bSave");
		
		bExit.addActionListener(this);
		bSave.addActionListener(this);
		
		toolBar.add(bExit);
		toolBar.add(bSave);
		
		// Normales Spiel und Spiel laden
		if (wt <= 1) {
			this.setFrameIcon(iconFrame);
			this.setTitle("Spiel");
			
			// Toolbar
			bUndo.setActionCommand("bUndo");
			bUndo.addActionListener(this);
			toolBar.add(bUndo);
		
		// Editor
		} else if (wt == 2) {
			this.setFrameIcon(iconEditor);
			this.setTitle("Spielfeld-Editor");
			
			// Editor
			bField.setActionCommand("bField");
			bField.addActionListener(this);
			toolBar.add(bField);
			bField.setText("Festes Feld");
		}
		
		// Spielbrett aufbauen
		pBoard.setLayout(new FlowLayout());
		this.add(BorderLayout.NORTH, toolBar);
		this.add(BorderLayout.CENTER, pBoard);
		this.board = new Board(pBoard, this, difficulty);
	}
	
	public void actionPerformed(ActionEvent e) {
		String a = e.getActionCommand();
		
		// Beenden
		if (a.equals("bExit")) {
			try {
				this.setClosed(true);
			} catch (Exception ex) { }
		}
		
		// Speichern
		if (a.equals("bSave")) {
			// nderungen in die Datenhaltung schreiben
			this.board.GUIToGameData();
			
			// Dateiauswahldialog schner machen
			saveDialog.setFileSelectionMode(JFileChooser.FILES_ONLY);
			saveDialog.setFileFilter(new FileFilter() {
				public boolean accept(File f) {
					return f.isDirectory() || f.getName().toLowerCase().endsWith(".sudoku");
				}
				public String getDescription() {
					return "Sudoku-Spiel (.sudoku)";
				}
			});
			
			// Datei auswhlen
			int res_file = saveDialog.showSaveDialog(this);
			
			// Datei angegeben, weiter mit der Speicherung
			if (res_file == JFileChooser.APPROVE_OPTION) {
				String filename = "" + saveDialog.getSelectedFile().getName();
				
				// Mit dem Editor erstelltes Spiel?
				if (wt == 2) {
					// Puzzle-Daten alle auf -1
					for (int y=0; y<9; y++) {
						for (int x=0; x<9; x++) {
							this.gameData.puzzle[x][y] = -1;
						}
					}
				}
				
				try {
					// Speichern
					FileOutputStream fs = new FileOutputStream(filename);
					ObjectOutputStream os = new ObjectOutputStream(fs);

					os.writeObject(this.gameData);
					os.close();
					
				} catch (IOException ex) {
					ex.printStackTrace();
				}
			}
		}

		if (a.equals("bRedo")) {		
			//board.reDo();
		}
		
		if (a.equals("bUndo")) {		
			board.unDo();
		}
		
		if (a.equals("bField")) {
			if (bField.isSelected()) {
				// Feste Felder setzen
				bField.setIcon(iconEditable);
				bField.setText("Variables Feld");
			} else {
				// Variable Felder setzen
				bField.setIcon(iconFixed);
				bField.setText("Festes Feld");
			}
		}
	}
}